@@ -147,7 +147,7 @@
     <message>
         <location filename="../devicewidget.ui" line="238"/>
         <source>&lt;b&gt;Latency offset:&lt;/b&gt;</source>
-        <translation>&lt;b&gt;Время задержки:&lt;/b&gt;</translation>
+        <translation>&lt;b&gt;Смещение задержки:&lt;/b&gt;</translation>
     </message>
     <message>
         <location filename="../devicewidget.ui" line="245"/>
@@ -528,12 +528,12 @@
     <message>
         <location filename="../pavucontrol.cc" line="622"/>
         <source>Connection to PulseAudio failed. Automatic retry in 5s.&lt;br&gt;&lt;br&gt;In this case this is likely because PULSE_SERVER in the Environment/X11 Root Window Propertiesor default-server in client.conf is misconfigured.&lt;br&gt;This situation can also arrise when PulseAudio crashed and left stale details in the X11 Root Window.&lt;br&gt;If this is the case, then PulseAudio should autospawn again, or if this is not configured you shouldrun start-pulseaudio-x11 manually.</source>
-        <translation type="unfinished"></translation>
+        <translation>Не удалось подключиться к PulseAudio. Автоматическая повторная попытка через 5 секунд.&lt;br&gt;&lt;br&gt;В данном случае это, вероятно, связано с неправильной настройкой PULSE_SERVER в свойствах корневого окна Environment/X11 или default-server в client.conf.&lt;br&gt;Такая ситуация также может возникнуть, когда PulseAudio выходит из строя и оставляет устаревшие сведения в корневом окне X11.&lt;br&gt;Если это так, то PulseAudio следует снова запустить автоматически, или, если это не настроено, вам следует запустить start-pulseaudio-x11 вручную.</translation>
     </message>
     <message>
         <location filename="../pavucontrol.cc" line="672"/>
         <source>Select a specific tab on load.</source>
-        <translation>Выбрать вкладку на загрузку.</translation>
+        <translation>Выбрать определённую вкладку при загрузке.</translation>
     </message>
     <message>
         <location filename="../pavucontrol.cc" line="675"/>
