@@ -528,7 +528,7 @@
     <message>
         <location filename="../pavucontrol.cc" line="622"/>
         <source>Connection to PulseAudio failed. Automatic retry in 5s.&lt;br&gt;&lt;br&gt;In this case this is likely because PULSE_SERVER in the Environment/X11 Root Window Propertiesor default-server in client.conf is misconfigured.&lt;br&gt;This situation can also arrise when PulseAudio crashed and left stale details in the X11 Root Window.&lt;br&gt;If this is the case, then PulseAudio should autospawn again, or if this is not configured you shouldrun start-pulseaudio-x11 manually.</source>
-        <translation type="unfinished"></translation>
+        <translation>Anslutning till PulseAudio misslyckades. Försök automatiskt igen om 5s.&lt;br&gt;&lt;br&gt;I det här fallet beror det troligen på att PULSE_SERVER i Miljön/X11 Root Fönsteregenskaper eller standardservern i client.conf är felkonfigurerad.&lt;br&gt;Den här situationen kan också uppstå när PulseAudio kraschade och lämnade inaktuella detaljer i X11 Root fönster.&lt;br&gt;Om så är fallet bör PulseAudio automatiskt starta upp igen, eller om detta inte är konfigurerat bör du köra start-pulseaudio-x11 manuellt.</translation>
     </message>
     <message>
         <location filename="../pavucontrol.cc" line="672"/>
